@@ -8,15 +8,21 @@ import copy
 import atexit
 import time
 import timeago
-
 from datetime import datetime
-
 import paho.mqtt.client as mqtt
-
 import meshtastic
 from pubsub import pub
-
 import configparser
+from pkg_resources import get_distribution, DistributionNotFound
+import os.path
+
+try:
+    _dist = get_distribution('iMesh-Dashboard')
+except DistributionNotFound:
+    __version__ = 'Unknown version'
+else:
+    __version__ = _dist.version
+
 dataPath = '/usr/local/iMeshDashboard'
 config = configparser.ConfigParser()
 config.read(dataPath+'/conf/app.conf')
@@ -32,8 +38,6 @@ interface = meshtastic.SerialInterface()
 
 client = mqtt.Client()
 client.username_pw_set(username=config['MQTT']['username'], password=config['MQTT']['password'])
-print(config['MQTT']['enabled'])
-
 
 app = Flask(__name__, template_folder=dataPath+'/templates')
 
@@ -42,6 +46,8 @@ app.config['BASIC_AUTH_PASSWORD'] = config['AUTH']['password']
 
 basic_auth = BasicAuth(app)
 
+appData = {"version":__version__}
+
 def sendPosition():
     print("Sending Position Beacon")
     interface.sendPosition(float(config['Position']['lat']), float(config['Position']['lon']), int(config['Position']['alt']), int(time.time()))
@@ -91,26 +97,21 @@ def updateImeshMap(interface, packet):
             print("Pushing received node info")
             client.publish("meshInfo/hopInfo", json.dumps({"receivedNode":packet.get('fromId'), "receiverNode":myNodeInfo['user']['id'],
                            "hopLimit":packet.get('hopLimit'), "rxTime":packet.get('rxTime')}))
-            print("pushed")
     try:
         for node, nodeValue in receivedNodes.items():
             try:
-                print(nodeValue['user']['longName'])
                 mapNodes.append([nodeValue['user']['longName'], nodeValue['position']['latitude'],
                                  nodeValue['position']['longitude'], getMapNodeInfo(nodeValue)[0], getMapNodeInfo(nodeValue)[1], getHourDiff(nodeValue['position']['time'])])
                 if node in oldReceivedNodes:
                     print(node +" - "+ nodeValue['user']['longName'] +" nodo presente")
-                    print(str(nodeValue['position']['time']) +" "+ str(oldReceivedNodes[node]['position']['time']))
                     if nodeValue['position']['time'] > oldReceivedNodes[node]['position']['time']:
-                        print(node +" - "+ nodeValue['user']['longName'] +" aggiornato")
+                        print("aggiornato")
                         client.publish("receivedNodes/"+node, json.dumps(nodeValue))
                 else:
                     print(" nuovo nodo ricevuto: "+node +" - "+ nodeValue['user']['longName'])
                     if(config['MQTT']['enabled']=="True"):
-                        print("--- --- ---")
-                        print(nodeValue)
                         client.publish("receivedNodes/"+node, json.dumps(nodeValue))
-                    print(str(nodeValue['position']['time']))
+                    print(str(nodeValue['position'].get('time')))
             except Exception as e:
                 print(e)
         oldReceivedNodes = copy.deepcopy(receivedNodes)
@@ -137,13 +138,12 @@ def getNodes():
     for node, value in receivedNodes.items():
         if (node == myNodeInfo['user']['id']):
             continue
-        print(value)
         if 'position' in value:
             lhTS = value['position'].get('time')
             if (lhTS is None) or (lhTS < (int(time.time())-86400)):
                 continue
-            if 'latitude' in value['position'] and 'longitude' in value['position'] and 'altitude' in value['position']:
-                pos = getFloat(value['position'].get('latitude')) +"°, "+getFloat(value['position'].get('longitude')) + "°, " + str(value['position'].get('altitude'))+"m"
+            if 'latitude' in value['position'] and 'longitude' in value['position']:
+                pos = getFloat(value['position'].get('latitude')) +"°, "+getFloat(value['position'].get('longitude')) + "°, " + str(value['position'].get('altitude', '---'))+"m"
             else:
                 pos=""
             lh = getLH(lhTS)
@@ -170,22 +170,34 @@ def send_js(path):
 @app.route('/css/<path:path>')
 def send_css(path):
     return send_from_directory(dataPath+'/css', path)
+@app.route('/img/<path:path>')
+def send_img(path):
+    return send_from_directory(dataPath+'/img', path)
 
 @app.route('/')
-@basic_auth.required
-def index():
+def indexPage():
     getNodes()
-    return render_template('index.html')
+    return render_template('index.html', Title="iMesh Node Landing Page", 
+                                         nodeInfo=myNodeInfo, info=interface.myInfo, appData=appData)
 
-@app.route('/public')
-def public():
+@app.route('/lh')
+def lhPage():
     getNodes()
-    return render_template('public.html')
+    return render_template('lh.html', Title="Last Heard", 
+                                      nodeInfo=myNodeInfo, appData=appData)
 
 @app.route('/map')
-def map():
+def mapPage():
     getNodes()
-    return render_template('map.html', nodesList=mapNodes)
+    return render_template('map.html', nodesList=mapNodes, Title="Nodes Map", 
+                                       nodeInfo=myNodeInfo, appData=appData)
+
+@app.route('/private/config')
+@basic_auth.required
+def configPage():
+    getNodes()
+    return render_template('config.html', Title="Nodes Map", 
+                                          nodeInfo=myNodeInfo, appData=appData)
 
 @app.route('/getNodes')
 def printNodes():
@@ -205,7 +217,7 @@ def sendMessage():
 
 @app.route('/setNode', methods=['POST'])
 @basic_auth.required
-def setData():
+def setNode():
     if request.method == 'POST':
         interface.setOwner(request.form['flongName'])
         prefs = interface.radioConfig.preferences
@@ -213,10 +225,14 @@ def setData():
         lat = float(request.form['flatitude'])
         lon = float(request.form['flongitude'])
         ts = int(time.time())
-        prefs.fixed_position = True
-        interface.sendPosition(lat, lon, alt, ts)
-        interface.writeConfig()
-    return redirect(url_for('index'))
+        if not interface.myInfo.has_gps and not (config['Position']['enabled']=='True'):
+            prefs.fixed_position = True
+            interface.sendPosition(lat, lon, alt, ts)
+            interface.writeConfig()
+        else:
+            print("Cannot set node parameters beacuse has gps: %s or has fixed position config in config file: %s" % 
+                   (interface.myInfo.has_gps, (config['Position']['enabled']=='True'),))
+    return redirect(url_for('configPage'))
 
 @app.route('/login', methods=['GET', 'POST'])
 def login():
@@ -234,9 +250,11 @@ def login():
     return flask.render_template('login.html', form=form)
 
 def main():
+    print("Starting iMeshDashboard v%s" % (__version__,))
+    print("MQTT ENABLED: %s" % config['MQTT']['enabled'])
     scheduler = APScheduler()
     if(config['Position']['enabled']=='True'):
-        print("setting postition info")
+        print("Setting postition info")
         scheduler.add_job(func=sendPosition, trigger='interval', id='sendPos', seconds=int(config['Position']['interval']))
         interface.sendPosition(float(config['Position']['lat']), float(config['Position']['lon']), int(config['Position']['alt']), int(time.time()))
         interface.writeConfig()
@@ -250,6 +268,8 @@ def main():
     pub.subscribe(updateImeshMap, "meshtastic.receive")
     atexit.register(lambda: interface.close())
     serve(app, host=config['NET']['bind'], port=config['NET']['port'])
+    #only for debug!
+    #app.run(debug=True, use_reloader=False)
 
 if __name__ == '__main__':
     main()
